pub struct AuditLog { /* private fields */ }Expand description
Persistent audit log that appends events to a JSON-lines file.
Thread-safe via internal Mutex. Supports size-based rotation.
Implementations
Sourceimpl AuditLog
impl AuditLog
Sourcepub fn new(path: impl Into<PathBuf>, config: AuditConfig) -> Result<Self>
pub fn new(path: impl Into<PathBuf>, config: AuditConfig) -> Result<Self>
Create a new audit log at the given path.
Sourcepub fn default_path() -> Result<Self>
pub fn default_path() -> Result<Self>
Open the audit log at the default path (~/.a3s/audit/audit.jsonl).
Sourcepub fn log(&self, event: &AuditEvent) -> Result<()>
pub fn log(&self, event: &AuditEvent) -> Result<()>
Append an audit event to the log.