Module box_record

Module box_record 

Canonical persisted metadata schema for local box executions.

Structs

BoxRecord
Metadata record for a single local box execution.
HealthCheck
Health-check behavior persisted with a local execution.
ManagedExecutionMetadata
Durable lifecycle metadata for an execution owned by ExecutionManager.
ManagedRestartCompletion
Restart identity retained after its transitional state has completed.

Enums

ManagedExecutionOperation
Recoverable backend operation associated with a transitional state.
ManagedExecutionState
Durable lifecycle state for an execution owned by ExecutionManager.
ManagedRestartOutcome
Durable result of the most recent restart operation.