Module rootfs_cache

Module rootfs_cache 

Cache for fully-built rootfs directories.

Avoids rebuilding the rootfs from OCI layers when the same image configuration has been seen before. The cache key is a SHA256 hash of the image reference, layer digests, entrypoint, and environment.

Structs

RootfsCache
Cache for fully-built rootfs directories.
RootfsMeta
Metadata for a cached rootfs entry.