pub struct FsManager { /* private fields */ }Expand description
Filesystem manager
Implementations
Sourceimpl FsManager
impl FsManager
Sourcepub fn add_mount(
&mut self,
host_path: impl AsRef<Path>,
guest_path: impl AsRef<Path>,
readonly: bool,
)
pub fn add_mount( &mut self, host_path: impl AsRef<Path>, guest_path: impl AsRef<Path>, readonly: bool, )
Add a mount point
Sourcepub fn setup_default_mounts(
&mut self,
workspace: impl AsRef<Path>,
cache: impl AsRef<Path>,
) -> Result<()>
pub fn setup_default_mounts( &mut self, workspace: impl AsRef<Path>, cache: impl AsRef<Path>, ) -> Result<()>
Setup default mounts for A3S Box
Sourcepub fn mounts(&self) -> &[MountPoint]
pub fn mounts(&self) -> &[MountPoint]
Get all mount points
Sourcepub async fn apply_mounts(&self) -> Result<()>
pub async fn apply_mounts(&self) -> Result<()>
Validate and log all configured mounts.
The actual virtio-fs device setup is handled by the shim via InstanceSpec.
This method validates that mount source paths exist on the host.