pub struct LocalExecutionTermination {
pub outcome: KillOutcome,
pub exit_code: Option<i32>,
}Expand description
Result of a terminal backend operation, including authoritative status when the runtime was able to observe it before teardown.
Fields
outcome: KillOutcomeexit_code: Option<i32>Trait Implementations
Sourceimpl Clone for LocalExecutionTermination
impl Clone for LocalExecutionTermination
Sourcefn clone(&self) -> LocalExecutionTermination
fn clone(&self) -> LocalExecutionTermination
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for LocalExecutionTermination
Sourceimpl Debug for LocalExecutionTermination
impl Debug for LocalExecutionTermination
impl Eq for LocalExecutionTermination
impl StructuralPartialEq for LocalExecutionTermination