pub struct OciBundlePreparationContext { /* private fields */ }Expand description
Stable runtime identities and negotiated capabilities available to product preparation.
Implementations
Sourceimpl OciBundlePreparationContext
impl OciBundlePreparationContext
Sourcepub fn runtime_container_id(&self) -> &ContainerId
pub fn runtime_container_id(&self) -> &ContainerId
Exact runtime container identity derived from the Box execution identity.
Sourcepub fn create_context(&self) -> &OperationContext
pub fn create_context(&self) -> &OperationContext
Exact create operation context that will be sent to OCI Runtime.
Sourcepub fn isolation(&self) -> &IsolationRequest
pub fn isolation(&self) -> &IsolationRequest
Minimum isolation requested from OCI Runtime.
Sourcepub fn attachment_capabilities(&self) -> &AttachmentCapabilities
pub fn attachment_capabilities(&self) -> &AttachmentCapabilities
Attachment extensions advertised by the connected runtime service.
Sourcepub fn runtime_bundle_handoff_directory(
&self,
runtime_root: impl AsRef<Path>,
) -> ExecutionManagerResult<PathBuf>
pub fn runtime_bundle_handoff_directory( &self, runtime_root: impl AsRef<Path>, ) -> ExecutionManagerResult<PathBuf>
Resolve the only operation-scoped directory accepted for bundle ownership handoff.
Sourcepub fn validate_runtime_bundle_handoff_directory(
&self,
directory: &Path,
) -> ExecutionManagerResult<()>
pub fn validate_runtime_bundle_handoff_directory( &self, directory: &Path, ) -> ExecutionManagerResult<()>
Verify that a claimed handoff directory has the exact negotiated suffix.