pub struct OciPreparedExecution {
pub bundle: OciBundle,
pub attachments: CreateAttachments,
pub console_log: PathBuf,
pub anonymous_volumes: Vec<String>,
}Expand description
Product-owned OCI bundle and host bookkeeping required before lifecycle launch.
Fields
bundle: OciBundleattachments: CreateAttachmentsconsole_log: PathBufanonymous_volumes: Vec<String>Implementations
Sourceimpl OciPreparedExecution
impl OciPreparedExecution
Sourcepub fn new(
bundle: OciBundle,
console_log: impl Into<PathBuf>,
) -> ExecutionManagerResult<Self>
pub fn new( bundle: OciBundle, console_log: impl Into<PathBuf>, ) -> ExecutionManagerResult<Self>
Build a non-interactive prepared execution with a caller-owned console.
Sourcepub fn with_attachments(
bundle: OciBundle,
attachments: CreateAttachments,
console_log: impl Into<PathBuf>,
) -> ExecutionManagerResult<Self>
pub fn with_attachments( bundle: OciBundle, attachments: CreateAttachments, console_log: impl Into<PathBuf>, ) -> ExecutionManagerResult<Self>
Build a prepared execution with explicit, already-authorized classifications.
Sourcepub fn with_runtime_bundle_handoff(
self,
context: &OciBundlePreparationContext,
runtime_root: impl AsRef<Path>,
) -> ExecutionManagerResult<Self>
pub fn with_runtime_bundle_handoff( self, context: &OciBundlePreparationContext, runtime_root: impl AsRef<Path>, ) -> ExecutionManagerResult<Self>
Bind a portable bundle prepared at the negotiated operation-scoped handoff path.