NetworkBackend

Trait NetworkBackend 

pub trait NetworkBackend: Send + Sync {
    // Required methods
    fn socket_path(&self) -> &Path;
    fn stop(&mut self);
}
Platform-agnostic handle to a running network backend process or thread.

Required Methods

fn socket_path(&self) -> &Path

Path to the Unix socket used to communicate with this backend.

fn stop(&mut self)

Stop the backend and clean up the socket.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors