pub fn default_provider() -> Box<dyn RootfsProvider>Expand description
Auto-detect the best available rootfs provider for the current platform.
pub fn default_provider() -> Box<dyn RootfsProvider>Auto-detect the best available rootfs provider for the current platform.