pub struct InstanceRegistry { /* private fields */ }Expand description
Registry for instance self-registration in standalone multi-node deployments.
Each Box host registers its instances with the registry so Gateway can discover endpoints for traffic routing.
Implementations
Sourceimpl InstanceRegistry
impl InstanceRegistry
Sourcepub fn register(
&mut self,
instance_id: &str,
service: &str,
endpoint: &str,
host_id: &str,
metadata: HashMap<String, String>,
)
pub fn register( &mut self, instance_id: &str, service: &str, endpoint: &str, host_id: &str, metadata: HashMap<String, String>, )
Register an instance.
Sourcepub fn deregister(&mut self, instance_id: &str) -> bool
pub fn deregister(&mut self, instance_id: &str) -> bool
Deregister an instance.
Sourcepub fn endpoints(&self, service: &str) -> Vec<String>
pub fn endpoints(&self, service: &str) -> Vec<String>
Get all endpoints for a service (for load balancing).
Sourcepub fn instances_for_service(&self, service: &str) -> Vec<&str>
pub fn instances_for_service(&self, service: &str) -> Vec<&str>
Get all instances for a service.
Sourcepub fn instances_on_host(&self, host_id: &str) -> Vec<&str>
pub fn instances_on_host(&self, host_id: &str) -> Vec<&str>
Get all instances on a specific host.
Sourcepub fn evict_stale(&mut self, max_age: Duration) -> Vec<String>
pub fn evict_stale(&mut self, max_age: Duration) -> Vec<String>
Remove stale entries that haven’t sent a heartbeat within the given duration.