pub fn load_resolved_image_config(
box_dir: &Path,
) -> Result<Option<SnapshotImageConfig>>Expand description
Load the resolved image defaults persisted for a box.
The artifact is independent of the control-plane process so a filesystem snapshot created after a service restart retains the source image’s OCI entrypoint, command, environment, working directory, and user.