LocalExecutionBackend

Trait LocalExecutionBackend 

pub trait LocalExecutionBackend: Send + Sync {
    // Required methods
    fn start<'life0, 'life1, 'async_trait>(
        &'life0 self,
        record: &'life1 BoxRecord,
    ) -> Pin<Box<dyn Future<Output = ExecutionManagerResult<LocalExecutionHandle>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn inspect<'life0, 'life1, 'async_trait>(
        &'life0 self,
        record: &'life1 BoxRecord,
    ) -> Pin<Box<dyn Future<Output = ExecutionManagerResult<LocalExecutionObservation>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn pause<'life0, 'life1, 'async_trait>(
        &'life0 self,
        record: &'life1 BoxRecord,
        keep_memory: bool,
    ) -> Pin<Box<dyn Future<Output = ExecutionManagerResult<LocalExecutionHandle>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn resume<'life0, 'life1, 'async_trait>(
        &'life0 self,
        record: &'life1 BoxRecord,
    ) -> Pin<Box<dyn Future<Output = ExecutionManagerResult<LocalExecutionHandle>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn kill<'life0, 'life1, 'async_trait>(
        &'life0 self,
        record: &'life1 BoxRecord,
    ) -> Pin<Box<dyn Future<Output = ExecutionManagerResult<KillOutcome>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;

    // Provided methods
    fn prepare_quiescent_rootfs<'life0, 'life1, 'async_trait>(
        &'life0 self,
        _record: &'life1 BoxRecord,
    ) -> Pin<Box<dyn Future<Output = ExecutionManagerResult<()>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait { ... }
    fn cleanup_quiescent_rootfs<'life0, 'life1, 'async_trait>(
        &'life0 self,
        _record: &'life1 BoxRecord,
    ) -> Pin<Box<dyn Future<Output = ExecutionManagerResult<()>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait { ... }
    fn stop_for_restart<'life0, 'life1, 'async_trait>(
        &'life0 self,
        record: &'life1 BoxRecord,
        _timeout_secs: Option<u64>,
    ) -> Pin<Box<dyn Future<Output = ExecutionManagerResult<KillOutcome>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait { ... }
}
Backend operations invoked outside the durable state lock.

Implementations must key all host/runtime paths by BoxRecord::id. The external sandbox ID in managed metadata is an untrusted diagnostic label.

Required Methods

fn start<'life0, 'life1, 'async_trait>( &'life0 self, record: &'life1 BoxRecord, ) -> Pin<Box<dyn Future<Output = ExecutionManagerResult<LocalExecutionHandle>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

fn inspect<'life0, 'life1, 'async_trait>( &'life0 self, record: &'life1 BoxRecord, ) -> Pin<Box<dyn Future<Output = ExecutionManagerResult<LocalExecutionObservation>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

fn pause<'life0, 'life1, 'async_trait>( &'life0 self, record: &'life1 BoxRecord, keep_memory: bool, ) -> Pin<Box<dyn Future<Output = ExecutionManagerResult<LocalExecutionHandle>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

fn resume<'life0, 'life1, 'async_trait>( &'life0 self, record: &'life1 BoxRecord, ) -> Pin<Box<dyn Future<Output = ExecutionManagerResult<LocalExecutionHandle>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

fn kill<'life0, 'life1, 'async_trait>( &'life0 self, record: &'life1 BoxRecord, ) -> Pin<Box<dyn Future<Output = ExecutionManagerResult<KillOutcome>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Provided Methods

fn prepare_quiescent_rootfs<'life0, 'life1, 'async_trait>( &'life0 self, _record: &'life1 BoxRecord, ) -> Pin<Box<dyn Future<Output = ExecutionManagerResult<()>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Make a stopped, storage-retained rootfs available for a filesystem snapshot without starting the execution runtime.

fn cleanup_quiescent_rootfs<'life0, 'life1, 'async_trait>( &'life0 self, _record: &'life1 BoxRecord, ) -> Pin<Box<dyn Future<Output = ExecutionManagerResult<()>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Release any transient rootfs mount created by Self::prepare_quiescent_rootfs while retaining guest data.

fn stop_for_restart<'life0, 'life1, 'async_trait>( &'life0 self, record: &'life1 BoxRecord, _timeout_secs: Option<u64>, ) -> Pin<Box<dyn Future<Output = ExecutionManagerResult<KillOutcome>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Stop the current runtime while preserving execution-owned storage for the replacement generation.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors