pub trait NetworkBackend: Send + Sync {
// Required methods
fn socket_path(&self) -> &Path;
fn stop(&mut self);
}Expand description
Platform-agnostic handle to a running network backend process or thread.
Required Methods
Sourcefn socket_path(&self) -> &Path
fn socket_path(&self) -> &Path
Path to the Unix socket used to communicate with this backend.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".