pub struct RunBindMount {
pub raw: String,
pub from: Option<String>,
pub source: String,
pub target: String,
pub read_write: bool,
}Expand description
Supported subset of Docker BuildKit RUN --mount=type=bind.
Fields
raw: Stringfrom: Option<String>Optional source stage/index. None means the build context.
source: StringSource path inside the build context or source stage. Defaults to root.
target: StringTarget path inside the build rootfs; relative targets resolve from WORKDIR.
read_write: boolrw/readwrite allows writes during RUN. Like BuildKit, writes are
discarded after the RUN and are not committed into the image layer.