Guest rootfs management module.
This module handles preparation and management of guest rootfs for MicroVM instances. The rootfs contains the minimal filesystem required to boot the guest agent.
Two rootfs providers are available:
CopyProvider— full recursive copy (works everywhere)OverlayProvider— Linux overlayfs mount (near-instant CoW)
Structs
- Copy
Provider - Full recursive copy provider — works on all platforms.
- Guest
Layout - Guest filesystem layout.
- Overlay
Provider - Overlayfs provider — near-instant CoW mounts (Linux only).
- Rootfs
Builder - Builder for creating guest rootfs.
Constants
- GUEST_
WORKDIR - Working directory inside the guest VM.
Traits
- Rootfs
Provider - Abstracts how a rootfs directory is prepared for a box from a cached lower layer.
Functions
- default_
provider - Auto-detect the best available rootfs provider for the current platform.
- unmount_
box_ overlay - Unmount a box’s overlayfs
mergedview — best-effort and idempotent.